K-Means Clustering {#tutorial_py_kmeans_index}
==================

-   @subpage tutorial_py_kmeans_understanding

    Read to get an intuitive understanding of K-Means Clustering

-   @subpage tutorial_py_kmeans_opencv

    Now let's try K-Means functions in OpenCV
